Miscellaneous
=============

.. autoclass:: pyhmmer.plan7.Cutoffs
   :members:

.. autoclass:: pyhmmer.plan7.EvalueParameters
   :members:

.. autoclass:: pyhmmer.plan7.Offsets
   :members:

.. autoclass:: pyhmmer.plan7.Transitions(enum.IntEnum)

   .. autoattribute:: MM

      :math:`M_{i} \to M_{i+1}`.
   
   .. autoattribute:: MI
      
      :math:`M_{i} \to I_{i+1}`.
   
   .. autoattribute:: MD
      
      :math:`M_{i} \to D_{i+1}`.
   
   .. autoattribute:: IM
      
      :math:`I_{i} \to M_{i+1}`.
   
   .. autoattribute:: II
      
      :math:`I_{i} \to I_{i+1}`.
   
   .. autoattribute:: DM

      :math:`D_{i} \to M_{i+1}`.
   
   .. autoattribute:: DD

      :math:`D_{i} \to D_{i+1}`.
